@@ -1,27 +1,32 @@
-# @(#)$Ident: Storage.pm 2013-09-29 01:02 pjf ;
+# @(#)$Ident: Storage.pm 2013-12-31 18:24 pjf ;
 
 package File::Gettext::Storage;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.22.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
+use Moo;
 use File::Basename             qw( basename );
 use File::DataClass::Constants;
 use File::DataClass::Functions qw( is_stale merge_file_data throw );
 use File::DataClass::Types     qw( Object );
 use File::Gettext;
-use Moo;
 use Try::Tiny;
+use Unexpected::Functions      qw( NothingUpdated Unspecified );
 
-has 'gettext' => is => 'lazy', isa => Object;
+has 'gettext' => is => 'lazy', isa => Object, builder => sub {
+   File::Gettext->new( builder   => $_[ 0 ]->schema,
+                       localedir => $_[ 0 ]->localedir );
+};
 
 has 'schema'  => is => 'ro',   isa => Object,  required => TRUE,
-   handles    => [ qw(cache lang localedir) ], weak_ref => TRUE;
+   handles    => [ qw( cache lang localedir ) ], weak_ref => TRUE;
 
 has 'storage' => is => 'ro',   isa => Object,  required => TRUE,
-   handles    => [ qw(extn meta_pack meta_unpack read_file txn_do
-                      validate_params) ];
+   handles    => [ qw( extn meta_pack meta_unpack
+                       read_file txn_do validate_params ) ];
 
+# Public methods
 sub delete {
    my ($self, $path, $result) = @_;
 
@@ -89,11 +94,8 @@ sub load {
    for my $path (@paths) {
       my ($red, $path_mtime) = $self->read_file( $path, FALSE );
 
-      if ($red) {
-         $path_mtime > $newest and $newest = $path_mtime;
-         merge_file_data $data, $red;
-      }
-
+      merge_file_data $data, $red;
+      $path_mtime > $newest and $newest = $path_mtime;
       $path_mtime = $self->_load_gettext( $data, $path );
       $path_mtime and $path_mtime > $newest and $newest = $path_mtime;
    }
@@ -116,24 +118,13 @@ sub update {
 }
 
 # Private methods
-sub _extn {
-   my $extn = (split m{ \. }mx, ($_[ 1 ] || NUL))[ -1 ];
-
-   return $extn ? ".${extn}" : $_[ 0 ]->extn;
-}
-
-sub _build_gettext {
-   return File::Gettext->new( builder   => $_[ 0 ]->schema,
-                              localedir => $_[ 0 ]->localedir );
-}
-
 sub _create_or_update {
    my ($self, $path, $result, $updating) = @_;
 
    my $source    = $result->_resultset->source;
    my $condition = sub { not $source->lang_dep->{ $_[ 0 ] } };
-   my $updated   = $self->storage->create_or_update( $path, $result,
-                                                     $updating, $condition );
+   my $updated   = $self->storage->create_or_update
+      ( $path, $result, $updating, $condition );
    my $rs        = $self->_gettext( $path )->resultset;
    my $element   = $source->name;
 
@@ -151,43 +142,47 @@ sub _create_or_update {
          $name = $updating ? $rs->create_or_update( $attrs )
                            : $rs->create( $attrs );
       }
-      catch { $_->class ne q(NothingUpdated) and throw $_ };
+      catch { $_->class ne NothingUpdated and throw $_ };
 
       $updated ||= $name ? TRUE : FALSE;
    }
 
-   $updating and not $updated
-      and throw class => q(NothingUpdated), error => 'Nothing updated',
-                level => 4;
+   $updating and not $updated and throw class => NothingUpdated, level => 4;
+   $updated  and $path->touch;
+   return $updated;
+}
 
-   $updated and $path->touch; return $updated;
+sub _extn {
+   my $extn = (split m{ \. }mx, ($_[ 1 ] || NUL))[ -1 ];
+
+   return $extn ? ".${extn}" : $_[ 0 ]->extn;
 }
 
 sub _get_key_and_newest {
    my ($self, $paths) = @_; my $key; my $newest = 0; my $valid = TRUE;
 
-   for my $path (grep { length } map { NUL.$_ } @{ $paths }) {
-      $key .= $key ? q(~).$path : $path;
+   for my $path (grep { length } map { "${_}" } @{ $paths }) {
+      $key .= $key ? "~${path}" : $path;
 
       my $mtime = $self->cache->get_mtime( $path );
 
       if ($mtime) { $mtime > $newest and $newest = $mtime }
       else { $valid = FALSE }
 
-      my $file      = basename( NUL.$path, $self->_extn( $path ) );
+      my $file      = basename( "${path}", $self->_extn( $path ) );
       my $lang_path = $self->gettext->get_path( $self->lang, $file );
 
-      if (defined ($mtime = $self->cache->get_mtime( NUL.$lang_path ))) {
+      if (defined ($mtime = $self->cache->get_mtime( "${lang_path}" ))) {
          if ($mtime) {
-            $key .= $key ? q(~).$lang_path : $lang_path;
+            $key .= $key ? "~${lang_path}" : $lang_path;
             $mtime > $newest and $newest = $mtime;
          }
       }
       else {
          if (-f $lang_path) {
-            $key .= $key ? q(~).$lang_path : $lang_path; $valid = FALSE;
+            $key .= $key ? "~${lang_path}" : $lang_path; $valid = FALSE;
          }
-         else { $self->cache->set_mtime( NUL.$lang_path, 0 ) }
+         else { $self->cache->set_mtime( "${lang_path}", 0 ) }
       }
    }
 
@@ -197,9 +192,11 @@ sub _get_key_and_newest {
 sub _gettext {
    my ($self, $path) = @_; my $gettext = $self->gettext;
 
-   $path or throw 'Path not specified'; my $extn = $self->_extn( $path );
+   $path or throw class => Unspecified, args => [ 'Path name' ];
 
-   $gettext->set_path( $self->lang, basename( NUL.$path, $extn ) );
+   my $extn = $self->_extn( $path );
+
+   $gettext->set_path( $self->lang, basename( "${path}", $extn ) );
 
    return $gettext;
 }
@@ -224,12 +221,12 @@ sub _load_gettext {
    return $gettext->path->stat->{mtime};
 }
 
-# Private subroutines
+# Private functions
 sub __get_attributes {
    my ($condition, $source) = @_;
 
    return grep { not m{ \A _ }msx
-                 and $_ ne q(name)
+                 and $_ ne 'name'
                  and $condition->( $_ ) } @{ $source->attributes || [] };
 }
 
@@ -245,7 +242,7 @@ File::Gettext::Storage - Split/merge language dependent data
 
 =head1 Version
 
-This document describes v0.21.$Rev: 1 $ of L<File::Gettext::Storage>
+This document describes v0.22.$Rev: 1 $ of L<File::Gettext::Storage>
 
 =head1 Synopsis
 
@@ -345,7 +342,7 @@ Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2014 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
